Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4983)

Unified Diff: chrome/common/chrome_switches.cc

Issue 267132: Http Cache: Enable byte-range support by default.... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/chrome_switches.h ('k') | chrome/renderer/render_process.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/chrome_switches.cc
===================================================================
--- chrome/common/chrome_switches.cc (revision 29212)
+++ chrome/common/chrome_switches.cc (working copy)
@@ -626,8 +626,8 @@
const char kEnableGView[] = "enable-gview";
#endif
-// Enable experimental support for cached byte-ranges.
-const char kEnableByteRangeSupport[] = "enable-byte-range-support";
+// Disable support for cached byte-ranges.
+const char kDisableByteRangeSupport[] = "disable-byte-range-support";
// Explicitly allow additional ports using a comma separated list of port
// numbers.
« no previous file with comments | « chrome/common/chrome_switches.h ('k') | chrome/renderer/render_process.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698